@@ -1,4 +1,4 @@
-#   Copyright 2024 The PyMC Developers
+#   Copyright 2024 - present The PyMC Developers
 #
 #   Licensed under the Apache License, Version 2.0 (the "License");
 #   you may not use this file except in compliance with the License.
@@ -247,7 +247,9 @@ class MvNormal(Continuous):
         data = np.random.multivariate_normal(mu, true_cov, 10)
 
         sd_dist = pm.Exponential.dist(1.0, shape=3)
-        chol, corr, stds = pm.LKJCholeskyCov("chol_cov", n=3, eta=2, sd_dist=sd_dist, compute_corr=True)
+        chol, corr, stds = pm.LKJCholeskyCov(
+            "chol_cov", n=3, eta=2, sd_dist=sd_dist, compute_corr=True
+        )
         vals = pm.MvNormal("vals", mu=mu, chol=chol, observed=data)
 
     For unobserved values it can be better to use a non-centered
@@ -2055,14 +2057,12 @@ class KroneckerNormal(Continuous):
     rv_op = KroneckerNormalRV.rv_op
 
     @classmethod
-    def dist(cls, mu, covs=None, chols=None, evds=None, sigma=None, *args, **kwargs):
+    def dist(cls, mu, covs=None, chols=None, evds=None, sigma=0.0, *args, **kwargs):
         if len([i for i in [covs, chols, evds] if i is not None]) != 1:
             raise ValueError(
                 "Incompatible parameterization. Specify exactly one of covs, chols, or evds."
             )
 
-        sigma = sigma if sigma else 0
-
         if chols is not None:
             covs = [chol.dot(chol.T) for chol in chols]
         elif evds is not None:
@@ -2074,6 +2074,7 @@ class KroneckerNormal(Continuous):
                 covs.append(cov_i)
 
         mu = pt.as_tensor_variable(mu)
+        sigma = pt.as_tensor_variable(sigma)
 
         return super().dist([mu, sigma, *covs], **kwargs)
 
@@ -2793,9 +2794,9 @@ class ZeroSumNormal(Distribution):
 
         support_shape = pt.as_tensor(support_shape, dtype="int64", ndim=1)
 
-        assert n_zerosum_axes == pt.get_vector_length(
-            support_shape
-        ), "support_shape has to be as long as n_zerosum_axes"
+        assert n_zerosum_axes == pt.get_vector_length(support_shape), (
+            "support_shape has to be as long as n_zerosum_axes"
+        )
 
         return super().dist([sigma, support_shape], **kwargs)
 
