@@ -13,11 +13,9 @@
 #   limitations under the License.
 
 import io
-import itertools as it
 
 from os import path
 
-import cloudpickle
 import numpy as np
 import pytensor
 import pytensor.tensor as pt
@@ -29,7 +27,7 @@ from pytensor.tensor.variable import TensorVariable
 import pymc as pm
 
 from pymc.data import MinibatchOp
-from pymc.pytensorf import GeneratorOp, floatX
+from pymc.pytensorf import floatX
 
 
 class TestData:
@@ -495,97 +493,6 @@ def integers_ndim(ndim):
         i += 1
 
 
-@pytest.mark.usefixtures("strict_float32")
-class TestGenerator:
-    def test_basic(self):
-        generator = pm.GeneratorAdapter(integers())
-        gop = GeneratorOp(generator)()
-        assert gop.tag.test_value == np.float32(0)
-        f = pytensor.function([], gop)
-        assert f() == np.float32(0)
-        assert f() == np.float32(1)
-        for _ in range(2, 100):
-            f()
-        assert f() == np.float32(100)
-
-    def test_ndim(self):
-        for ndim in range(10):
-            res = list(it.islice(integers_ndim(ndim), 0, 2))
-            generator = pm.GeneratorAdapter(integers_ndim(ndim))
-            gop = GeneratorOp(generator)()
-            f = pytensor.function([], gop)
-            assert ndim == res[0].ndim
-            np.testing.assert_equal(f(), res[0])
-            np.testing.assert_equal(f(), res[1])
-
-    def test_cloning_available(self):
-        gop = pm.generator(integers())
-        res = gop**2
-        shared = pytensor.shared(pm.floatX(10))
-        res1 = pytensor.clone_replace(res, {gop: shared})
-        f = pytensor.function([], res1)
-        assert f() == np.float32(100)
-
-    def test_default_value(self):
-        def gen():
-            for i in range(2):
-                yield pm.floatX(np.ones((10, 10)) * i)
-
-        gop = pm.generator(gen(), np.ones((10, 10)) * 10)
-        f = pytensor.function([], gop)
-        np.testing.assert_equal(np.ones((10, 10)) * 0, f())
-        np.testing.assert_equal(np.ones((10, 10)) * 1, f())
-        np.testing.assert_equal(np.ones((10, 10)) * 10, f())
-        with pytest.raises(ValueError):
-            gop.set_default(1)
-
-    def test_set_gen_and_exc(self):
-        def gen():
-            for i in range(2):
-                yield pm.floatX(np.ones((10, 10)) * i)
-
-        gop = pm.generator(gen())
-        f = pytensor.function([], gop)
-        np.testing.assert_equal(np.ones((10, 10)) * 0, f())
-        np.testing.assert_equal(np.ones((10, 10)) * 1, f())
-        with pytest.raises(StopIteration):
-            f()
-        gop.set_gen(gen())
-        np.testing.assert_equal(np.ones((10, 10)) * 0, f())
-        np.testing.assert_equal(np.ones((10, 10)) * 1, f())
-
-    def test_pickling(self, datagen):
-        gen = pm.generator(datagen)
-        cloudpickle.loads(cloudpickle.dumps(gen))
-        bad_gen = pm.generator(integers())
-        with pytest.raises(TypeError):
-            cloudpickle.dumps(bad_gen)
-
-    def test_gen_cloning_with_shape_change(self, datagen):
-        gen = pm.generator(datagen)
-        gen_r = pt.random.normal(size=gen.shape).T
-        X = gen.dot(gen_r)
-        res, _ = pytensor.scan(lambda x: x.sum(), X, n_steps=X.shape[0])
-        assert res.eval().shape == (50,)
-        shared = pytensor.shared(datagen.data.astype(gen.dtype))
-        res2 = pytensor.clone_replace(res, {gen: shared**2})
-        assert res2.eval().shape == (1000,)
-
-
-def gen1():
-    i = 0
-    while True:
-        yield np.ones((10, 100)) * i
-        i += 1
-
-
-def gen2():
-    i = 0
-    while True:
-        yield np.ones((20, 100)) * i
-        i += 1
-
-
 @pytest.mark.usefixtures("strict_float32")
 class TestMinibatch:
     data = np.random.rand(30, 10)
